#!/usr/bin/env python

"""
This module is part of the file integrity checker 'Spot The Difference'.
It subcalasses the generic class 'IntegrityChecker' to make it interact with
MySQL databases.
It only overrides the 'open_db' method.
"""


import MySQLdb
from spot import IntegrityChecker
from sys import exit


class spot(IntegrityChecker):

    """File integrity checker with MySQL database access"""

    def __init__(self, options, paths, vars_):
        """Call the parent __init__ method"""
        IntegrityChecker.__init__(self, options, paths, vars_)

    def open_db(self):
        """Connect to the database

        The parameters in the configuration file are used to connect to the
        database. The database object and the table name are returned. The
        'db_name' attribute is set to a string in the form:

          <db>.<table> on <host>

        as requested by the superclass.
        """
        kwargs = {}

        for key in ("user", "passwd", "host", "db"):
            try:
                kwargs[key] = self.vars[key]
            except:
                exit("Variable '%s' not set in file '%s'" %
                     (key, self.options.cfg_file))

        if self.vars.has_key("port"):
            kwargs["port"] = int(self.vars["port"])
        elif self.vars.has_key("unix_socket"):
            kwargs["unix_socket"] = self.vars["unix_socket"]
        else:
            exit("Variable 'port' or 'unix_socket' not set in file '%s'" %
                 self.options.cfg_file)

        try:
            table = self.vars["table"]
        except KeyError:
            exit("Variable 'table' not set in file '%s'" %
                 self.options.cfg_file)

        self.db_name = "%s.%s on %s" % (kwargs["db"], table, kwargs["host"])

        # Connect and select database
        try:
            db = apply(MySQLdb.connect, (), kwargs)
        except:
            exit("Could not connect to server '%s'" % kwargs["host"])
        else:
            return (db, table)

